@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_BACKEND_POSTGRES_H
@@ -49,7 +49,7 @@ public:
    */
   virtual bool save_backup(const SlotProgress& slot_progress, const Glib::ustring& username, const Glib::ustring& password, const Glib::ustring& database_name);
 
-  virtual bool convert_backup(const SlotProgress& slot_progress, const std::string& base_directory, const Glib::ustring& username, const Glib::ustring& password, const Glib::ustring& database_name);
+  virtual bool convert_backup(const SlotProgress& slot_progress, const std::string& backup_data_file_path, const Glib::ustring& username, const Glib::ustring& password, const Glib::ustring& database_name);
 
   /** Return the quoted path to the specified PostgreSQL utility.
    */
@@ -82,6 +82,7 @@ protected:
    */
   std::string get_self_hosting_data_path(bool create = false);
 
+  //TODO: Remove this?
   /** Get the path to the backup file, regardless of whether it exists.
    * @param base_directory Where to find the backup file, under a normal Glom directory structure.
    * If @a base_directory is empty then it uses get_database_directory_uri().
