@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_DATASTRUCTURE_LAYOUTITEM_PORTAL_H
@@ -31,6 +31,11 @@ namespace Glom
 
 class Document; //For the utility functions.
 
+/**
+ * get_title() returns either the title of the Field or the CustomTitle.
+ * You should not call get/set_title_original() or get/set_title_translation()
+ * on items of this type.
+ */
 class LayoutItem_Portal
 : public LayoutGroup,
   public UsesRelationship
@@ -47,7 +52,12 @@ public:
 
   virtual LayoutItem* clone() const;
 
-  virtual Glib::ustring get_part_type_name() const;
+  virtual Glib::ustring get_title(const Glib::ustring& locale) const;
+  virtual Glib::ustring get_title_or_name(const Glib::ustring& locale) const;
+
+  //We do not implement this, because we only ever want to use the method
+  //in the derived class.
+  //virtual Glib::ustring get_part_type_name() const;
 
   virtual void change_field_item_name(const Glib::ustring& table_name, const Glib::ustring& field_name, const Glib::ustring& field_name_new);
   virtual void change_related_field_item_name(const Glib::ustring& table_name, const Glib::ustring& field_name, const Glib::ustring& field_name_new);
@@ -136,11 +146,11 @@ public:
   
   /** Get the number of rows that should be displayed.
    */
-  double get_rows_count() const;
+  void get_rows_count(gulong& rows_count_min, gulong& rows_count_max) const;
   
   /** Set the number of rows that should be displayed.
    */
-  void set_rows_count(double rows_count);
+  void set_rows_count(gulong rows_count_min, gulong rows_count_max);
 
 
 private:
@@ -159,7 +169,7 @@ private:
   //If no navigation relationship has been specified then it will be automatically chosen or navigation will be disabled:
   navigation_type m_navigation_type;
   
-  double m_rows_count;
+  gulong m_rows_count_min, m_rows_count_max;
 };
 
 } //namespace Glom
