@@ -464,11 +464,14 @@ public:
    */
   Glib::ustring save_backup_file(const Glib::ustring& uri, const SlotProgress& slot_progress);
   
-  /**
+  /** Extract the .glom file and backup data from a .tar.gz archive.
+   * The backup data must be stored temporarily on disk because pg_restore requires a file on disk.
+   *
    * @param backup_uri: The URI of a .tar.gz backup file.
-   * @result The URI of the restored .glom file.
+   * @param backup_path This will be set to the path of a temporary file for use with pg_restore.
+   * @result The contents of the .glom file from the .tar.gz file.
    */
-  static Glib::ustring restore_backup_file(const Glib::ustring& backup_uri, const SlotProgress& slot_progress);
+  static Glib::ustring extract_backup_file(const Glib::ustring& backup_uri, std::string& backup_path, const SlotProgress& slot_progress);
   
 
 protected:
@@ -530,6 +533,25 @@ private:
   type_list_translatables get_translatable_report_items(const Glib::ustring& table_name, const Glib::ustring& report_name, const Glib::ustring& hint);
   type_list_translatables get_translatable_print_layout_items(const Glib::ustring& table_name, const Glib::ustring& print_layout_name, const Glib::ustring& hint);
 
+  /* For use when making save_backup_file() async.
+  class FileReadWriteToArchiveData
+  {
+    FileReadWriteToArchiveData()
+    : a(0)
+    {}
+
+    Glib::RefPtr<Gio::File> file;
+    Glib::RefPtr<Gio::FileInputStream> stream;
+
+    struct archive* a;
+    
+  private:
+    //Prevent copying:
+    FileReadWriteToArchiveData(const FileReadWriteToArchiveData& src);
+    FileReadWriteToArchiveData operator=(const FileReadWriteToArchiveData& src);
+  };
+  */
+
   AppState m_app_state;
   type_signal_userlevel_changed m_signal_userlevel_changed;
 
