@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "checkbutton.h"
@@ -36,7 +36,7 @@ CheckButton::CheckButton(const Glib::ustring& title)
   : Gtk::CheckButton(title)
 {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  setup_menu();
+  setup_menu(this);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   init();
@@ -48,7 +48,6 @@ CheckButton::~CheckButton()
 
 void CheckButton::init()
 {
-
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
