@@ -65,13 +65,23 @@ Dialog_FieldDefinition::Dialog_FieldDefinition(BaseObjectType* cobject, const Gl
   builder->get_widget("button_edit_calculation",  m_pButton_EditCalculation);
 
   //Connect signals:
+  if(m_pCombo_Type)
   m_pCombo_Type->signal_changed().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_combo_type_changed) );
-  m_pCombo_LookupRelationship->signal_changed().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_combo_lookup_relationship_changed) );
-  m_pCheck_Lookup->signal_toggled().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_check_lookup_toggled) );
 
-  m_pRadio_Calculate->signal_toggled().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_radio_calculate_toggled) );
-  m_pRadio_UserEntry->signal_toggled().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_radio_userentry_toggled) );
-  m_pButton_EditCalculation->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_button_edit_calculation) );
+  if(m_pCombo_LookupRelationship)
+    m_pCombo_LookupRelationship->signal_changed().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_combo_lookup_relationship_changed) );
+
+  if(m_pCheck_Lookup)
+    m_pCheck_Lookup->signal_toggled().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_check_lookup_toggled) );
+
+  if(m_pRadio_Calculate)
+    m_pRadio_Calculate->signal_toggled().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_radio_calculate_toggled) );
+
+  if(m_pRadio_UserEntry)
+    m_pRadio_UserEntry->signal_toggled().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_radio_userentry_toggled) );
+
+  if(m_pButton_EditCalculation)
+    m_pButton_EditCalculation->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_FieldDefinition::on_button_edit_calculation) );
 
   //TODO:
   //Connect every widget to on_anything_changed():
@@ -83,9 +93,9 @@ Dialog_FieldDefinition::Dialog_FieldDefinition(BaseObjectType* cobject, const Gl
   on_combo_type_changed();
 
 
-  on_foreach_connect(*this);
-  on_foreach_connect(*m_pBox_DefaultValueSimple);
-  on_foreach_connect(*m_pBox_ValueTab);
+  connect_each_widget(this);
+  connect_each_widget(m_pBox_DefaultValueSimple);
+  connect_each_widget(m_pBox_ValueTab);
 
   Dialog_Properties::set_modified(false);
 
@@ -140,11 +150,14 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
   if(!m_pDataWidget_DefaultValueSimple->get_data_child_widget())
     std::cerr << G_STRFUNC << ": The DataWidget did not create a child widget." << std::endl;
 
-  on_foreach_connect(*m_pDataWidget_DefaultValueSimple);
+  connect_each_widget(m_pDataWidget_DefaultValueSimple);
 
   Gtk::Label* pLabel = m_pDataWidget_DefaultValueSimple->get_label();
   if(!pLabel->get_text().empty())
-    m_pBox_DefaultValueSimple->pack_start(*pLabel);
+  {
+    pLabel->set_valign(Gtk::ALIGN_START); //Because the widget might be multiline.
+    m_pBox_DefaultValueSimple->pack_start(*pLabel, Gtk::PACK_SHRINK);
+  }
 
   m_pBox_DefaultValueSimple->pack_end(*m_pDataWidget_DefaultValueSimple, Gtk::PACK_EXPAND_WIDGET);
   m_pDataWidget_DefaultValueSimple->set_value(default_value);
@@ -360,7 +373,7 @@ void Dialog_FieldDefinition::on_button_edit_calculation()
   m_Field->set_calculation( m_pTextView_Calculation->get_buffer()->get_text() );
   dialog->set_field(m_Field, m_table_name);
   //TODO: dialog.set_transient_for(*get_app_window());
-  const int response = Glom::Utils::dialog_run_with_help(dialog);
+  const int response = Glom::UiUtils::dialog_run_with_help(dialog);
   if(response == Gtk::RESPONSE_OK)
   {
     m_pTextView_Calculation->get_buffer()->set_text( dialog->get_field()->get_calculation() );
