@@ -99,10 +99,10 @@ Box_Formatting::Box_Formatting(BaseObjectType* cobject, const Glib::RefPtr<Gtk::
   builder->get_widget("checkbutton_color_background", m_checkbox_format_text_color_background);
 
   //Set the adjustment details, to avoid a useless 0-to-0 range and a 0 incremenet.
-  //We don't do this the Glade file because GtkBuilder wouldn't find the
+  //We don't do this in the Glade file because GtkBuilder wouldn't find the
   //associated adjustment object unless we specified it explictly:
   //See http://bugzilla.gnome.org/show_bug.cgi?id=575714
-  m_spinbutton_format_text_multiline_height->set_range(0, 100);
+  m_spinbutton_format_text_multiline_height->set_range(1, 10000);
   m_spinbutton_format_text_multiline_height->set_increments(1, 10);
   m_spinbutton_format_text_multiline_height->set_value(3); //A sensible default.
 
@@ -159,17 +159,17 @@ Box_Formatting::Box_Formatting(BaseObjectType* cobject, const Glib::RefPtr<Gtk::
   m_button_choices_sortby->signal_clicked().connect( sigc::mem_fun(*this, &Box_Formatting::on_button_choices_sortby) );
 
   //TODO: Delay this until it is used?
-  if(!m_dialog_choices_extra_fields)
+  Utils::get_glade_widget_derived_with_warning(m_dialog_choices_extra_fields);
+  if(m_dialog_choices_extra_fields)
   {
-    Utils::get_glade_widget_derived_with_warning(m_dialog_choices_extra_fields);
     add_view(m_dialog_choices_extra_fields); //Give it access to the document.
     m_dialog_choices_extra_fields->set_title(_("Extra Fields"));
   }
 
   //TODO: Delay this until it is used?
-  if(!m_dialog_choices_sortby)
+  Utils::get_glade_widget_derived_with_warning(m_dialog_choices_sortby);
+  if(m_dialog_choices_sortby)
   {
-    Utils::get_glade_widget_derived_with_warning(m_dialog_choices_sortby);
     add_view(m_dialog_choices_sortby); //Give it access to the document.
     m_dialog_choices_sortby->set_title(_("Sort Order"));
   }
@@ -516,7 +516,7 @@ void Box_Formatting::enforce_constraints()
     else
     {
       m_checkbox_format_text_multiline->show();
-      m_label_format_text_multiline_height->hide();
+      m_label_format_text_multiline_height->show();
       m_spinbutton_format_text_multiline_height->show();
     }
 
@@ -572,7 +572,7 @@ void Box_Formatting::on_button_choices_extra()
   if(!m_dialog_choices_extra_fields)
     return;
 
-  const int response = Glom::Utils::dialog_run_with_help(m_dialog_choices_extra_fields);
+  const int response = Glom::UiUtils::dialog_run_with_help(m_dialog_choices_extra_fields);
   m_dialog_choices_extra_fields->hide();
   if(response == Gtk::RESPONSE_OK && m_dialog_choices_extra_fields->get_modified())
   {
@@ -591,7 +591,7 @@ void Box_Formatting::on_button_choices_sortby()
   if(!m_dialog_choices_sortby)
     return;
 
-  const int response = Glom::Utils::dialog_run_with_help(m_dialog_choices_sortby);
+  const int response = Glom::UiUtils::dialog_run_with_help(m_dialog_choices_sortby);
   m_dialog_choices_sortby->hide();
   if(response == Gtk::RESPONSE_OK && m_dialog_choices_sortby->get_modified())
   {
