@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_UTILITY_WIDGETS_IMAGE_GLOM_H
@@ -29,6 +29,7 @@
 #include <gtkmm/frame.h>
 #include <gtkmm/builder.h>
 #include <giomm/appinfo.h>
+#include <giomm/simpleactiongroup.h>
 #include <evince-view.h>
 
 namespace Glom
@@ -85,6 +86,8 @@ private:
 
   void setup_menu_usermode();
   void show_image_data();
+
+  void popup_menu(guint button, guint32 activate_time);
   
   const GdaBinary* get_binary() const;
   
@@ -116,9 +119,13 @@ private:
 
 
   Gtk::Menu* m_pMenuPopup_UserMode;
-  Glib::RefPtr<Gtk::ActionGroup> m_refActionGroup_UserModePopup;
-  Glib::RefPtr<Gtk::UIManager> m_refUIManager_UserModePopup;
-  Glib::RefPtr<Gtk::Action> m_refActionOpenFile, m_refActionOpenFileWith, 
+
+  //TODO: Use just the Gio::ActionGroup type when it derives from Gio::ActionMap. 
+  Glib::RefPtr<Gio::SimpleActionGroup> m_refActionGroup_UserModePopup;
+
+  //We use Gio::SimpleAction rather than Gio::Action
+  //because Gio::Action has no way to enable/disable it.
+  Glib::RefPtr<Gio::SimpleAction> m_refActionOpenFile, m_refActionOpenFileWith, 
     m_refActionSaveFile, m_refActionSelectFile, m_refActionCopy, m_refActionPaste, m_refActionClear;
 
   bool m_read_only;
